@@ -1,4 +1,4 @@
 test_that("ngram function returns a data frame", {
   result <- ngram(word = "havet", corpus = "bok")
-  expect_is(result, "data.frame")
+  expect_s3_class(result, "data.frame")
 })
